Capped Nanotubes

## 2.3 Capped Nanotubes

The input parameters for the construction of the capped nanotube are displayed in the Calculations–Input window as shown in Fig 4:

Figure 4: `NanoCap` input options for a capped nanotube

The following input options can be set for the capped nanotube construction.

- the chirality ()

- the length of the nanotube ()

- the number of cap carbon atoms and dual lattice points (or enabled the estimation based upon the nanotube density)

- the seed for the initial random cap point placement

- the force cutoff relating to the dual lattice force field (Section 4.1)

The process of generating a capped nanotube involves the construction of a finite length nanotube (as outlined in the previous section) and a hemispherical cap. The cap is produced in a similar manner to the fullerene:

|  |  | (10)

where is now taken in range [-1,0]. Using the symmetry of the nanotube, a copy of the primary cap is transformed to the opposing end of the nanotube to form an equivalent secondary cap. The points belonging to both caps and the nanotube are joined into a single set of points that are used in the optimisation routines (Section 5).